@@ -7,39 +7,39 @@ os.system("")  # print颜色开启(玄学)
 isPrint = True
 
 # 定义颜色，方便简打
-_color_black = "black"
-_color_red = "red"
-_color_green = "green"
-_color_yellow = "yellow"
-_color_blue = "blue"
-_color_purplered = "purple-red"
-_color_cyanine = "cyanine"
-_color_white = "white"
-_color_default = "default"
+__color_black = "black"
+__color_red = "red"
+__color_green = "green"
+__color_yellow = "yellow"
+__color_blue = "blue"
+__color_purplered = "purple-red"
+__color_cyanine = "cyanine"
+__color_white = "white"
+__color_default = "default"
 
-_background_black = "black"
-_background_red = "red"
-_background_green = "green"
-_background_yellow = "yellow"
-_background_blue = "blue"
-_background_purplered = "purple-red"
-_background_cyanine = "cyanine"
-_background_white = "white"
-_background_default = "default"
+__background_black = "black"
+__background_red = "red"
+__background_green = "green"
+__background_yellow = "yellow"
+__background_blue = "blue"
+__background_purplered = "purple-red"
+__background_cyanine = "cyanine"
+__background_white = "white"
+__background_default = "default"
 
-_effect_default = "default"
-_effect_highlight = "highlight"
-_effect_underline = "underline"
-_effect_flash = "flash"
-_effect_backwhite = "backwhite"
-_effect_unshow = "unshow"
+__effect_default = "default"
+__effect_highlight = "highlight"
+__effect_underline = "underline"
+__effect_flash = "flash"
+__effect_backwhite = "backwhite"
+__effect_unshow = "unshow"
 
-_Type_error = "error"
-_Type_warning = "warning"
-_Type_success = "success"
-_Type_data = "data"
-_Type_system = "system"
-_Type_normal = "normal"
+__Type_error = "error"
+__Type_warning = "warning"
+__Type_success = "success"
+__Type_data = "data"
+__Type_system = "system"
+__Type_normal = "normal"
 
 
 def set_isPrint(is_print=True):
@@ -134,5 +134,5 @@ def printf(
 
 
 if __name__ == '__main__':
-    printf("thgttr", "sdsdds", Type=_Type_error)
-    printf("ssdd", Type=_Type_system)
+    printf("thgttr", "sdsdds", Type=__Type_error)
+    printf("ssdd", Type=__Type_system)
